#
# spec file for package octave-forge-stk
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  stk
Name:           octave-forge-%{octpkg}
Version:        2.6.1
Release:        bp154.1.34
Summary:        Small Octave Toolbox for Kriging
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  octave-devel >= 3.8.0
Requires:       octave-cli >= 3.8.0

%description
The STK is a (not so) Small Toolbox for Kriging. Its primary focus
in on the interpolation/regression technique known as kriging, which
is very closely related to Splines and Radial Basis Functions, and can be
interpreted as a non-parametric Bayesian method using a Gaussian Process
(GP) prior. The STK also provides tools for the sequential and
non-sequential design of experiments. Even though it is, currently, mostly
geared towards the Design and Analysis of Computer Experiments (DACE), the
STK can be useful for other applications areas (such as Geostatistics,
Machine Learning, Non-parametric Regression, etc.).
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Wed Nov 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.6.1:
  * Documentation
    + stk_factorialdesign: Provide missing help text. (ticket #91)
    + Fix HTML doc (INDEX structure was broken).
- Update to version 2.6.0:
  * Required Octave version
    + Required Octave version number has been raised to 3.8.
  * Parameter estimation
    + stk_param_init: The syntax with an additional do_estim_lnv parameter
    is now deprecated. Set model.lognoisevariance to NaN if you want an
    initial estimate for the variance of the noise.
    + stk_param_init_lnv: Refuse noiseless models (error).
    + stk_model_gpposterior: Trigger parameter estimation when lognoisevariance
    is NaN. In the (experimental) case where lognoisevariance is a noise
    model object, parameter estimation is triggered as soon as at least one
    of the optimizable parameters of the model is NaN. (ticket #93)
    + stk_param_relik: Return [] instead of NaN when the derivative with
    respect to lnv is requested for a noiseless model.
    + stk_param_relik: Detect duplicated observation points automatically
    and raise an error for noiseless models.
    + stk_param_getdefaultbounds: Estimation bounds for the regularity parameter
    of the Matérn covariance function are now customizable through the options
    nu_min_dimfun and nu_max_dimfun.
  * Covariance functions
    + Deprecated: stk_noisecov.
  * Models
    + stk_get_input_data, stk_get_output_data, stk_get_prior_model: New getters
    for model properties, that replace get_input_data, get_output_data and
    get_prior_model respectively (now deprecated).
    + stk_get_observation_variances: New getter, which returns the vector of
    variances associated to the observations that have been used to build a model.
    + stk_gaussiannoise_, stk_gaussiannoise_het0: New classes representing Gaussian
    noise models. Currently in experimental state, these two classes are merely a
    proof-of-concept. Other noise model classes can be defined by subclassing
    stk_gaussiannoise_. (ticket #38)
    + stk_example_misc05: Demonstrate the use of noise model objects to estimate
    the dispersion parameter in an heteroscedatic case.
    + stk_simulate_noise: New function to simulate noise sample replicates.
  * stk_dataframe and related classes
    + stk_dataframe: Accept char vectors (or strings) as colnames or rownames
    argument when there is only one column or one row (ticket #92)
    + @stk_dataframe/sort: Argument dim can now be skipped, as in the base sort function.
    + @stk_dataframe/unique: Overload base function.
  * Graphics
    + stk_plot1d: Do not create a legend systematically. (ticket #82)
    + stk_legend: New function to create a legend, using the graphical objects for
    which a non-empty DisplayName has been provided.
    + stk_plot_shadedci: Change gray levels and improve legend.
  * Miscellaneous
    + stk_options_set: Make it possible to set all options at once using an option
    structure. Add help text.
    + stk_runtests: Return test results in a structure.
    + stk_sampling_nesteddesign: Fix help text.
* Wed Jul 18 2018 badshah400@gmail.com
- Update to version 2.5.1:
  * tk_dominatedhv: Workaround for Octave 4.4 issue (ticket #89)
  * Documentation fixes.
  * stk_option_set: Return option struct only if nargout > 0.
* Wed Sep 27 2017 badshah400@gmail.com
- Update to version 2.5.0
  * Required Octave version number has been raised to 3.6.0.
  * Sequential design of experiments:
  - `stk_sampcrit_akg_eval`: New function.  Computes the
    Approximate Knowledge Gradient (AKG) sampling criterion.
  - `stk_example_doe05`: Example script that demonstrates the
    use of the AKG and EQI sampling criteria for noisy
    optimization.
  - New (experimental) classes to represent sampling criterion
    objects: `stk_sampcrit_ei`, `stk_sampcrit_akg`,
    `stk_sampcrit_eqi`.
  - `stk_sampcrit_ei_eval`: Remove deprecated calling forms.
  * Design of experiments:
  - `stk_factorialdesign`: Accept one-variable `stk_dataframe`
    objects as factors and preserve column names in this case.
  - `stk_sampling_nesteddesign`: New function to create nested
    designs.
  - `stk_sampling_nestedlhs`: New function to create nested LHS
    (NLHS).
  - `stk_sampling_sobol`: Fix help text.
  * Validation of models:
  - `stk_distrib_normal_crps`: New function to compare
    observations and predictive (Gaussian) density.
  - Calling `stk_predict_leaveoneout` with no output arguments
    now automatically creates two cross-validation diagnostics
    in two subplots: prediction VS observations (left panel) and
    normalized residuals (right panel).
  - `stk_predict_leaveoneout` uses now the virtual LOO formula.
  * `stk_dataframe` and related classes
  - `stk_hrect`: Preserve column names for `stk_dataframe`
    inputs.
  - `@stk_dataframe/find`: Overload base function to support
    calling find with an stk_dataframe as first input argument.
  - `@stk_dataframe/plotmatrix`: Overload base function to
    enrich `plotmatrix` graphics with variable names when
    possible.
  * Logical functions:
  - Operations that normally return logical (`lt`, `eq`,
    `and`...) now return logical values for `stk_dataframe`
    arguments.
  - New overloaded functions for `stk_dataframe` objects:
    `isinf`, `isnan`, `isfinite`.
  * Testing array membership:
  - `@stk_dataframe/ismember`: No longer assumes `rows` flag for
    consistency with the base `ismember` function.
  - `stk_factorialdesign/ismember`: New function.  Tests
    membership for factorial designs much more efficiently than
    for plain arrays or data frames.
  * `stk_generate_samplepaths` now returns a plain numerical array instead of
    a data frame.
  * Miscellaneous:
  - `stk_plot_probdom2d`: New function to represent the
    uncertainty about a 2D Pareto front.  This function is
    currently considered experimental and should not be expected
    to produce a reliable representation of the uncertainty for
    difficult or high-dimensional optimization problems.
  - New test case: "truss3" (Koski, 1985; Das, 1997).
  - Many functions have been optimized for speed.
  - `stk_plot1d`: Handle the case where `xt` is not sorted.
  - Support old-style STK structures (with a `.a` field) has
    been removed.
* Wed Nov 11 2015 dmitry_r@opensuse.org
- Update to version 2.3.4
  * Bug fixes and minor changes
* Tue Oct 13 2015 dmitry_r@opensuse.org
- Update to version 2.3.3
  * Bug fixes and minor changes
* Tue Jul  7 2015 dmitry_r@opensuse.org
- Update to version 2.3.2
  * Bug fixes and minor changes
* Mon Jun 22 2015 dmitry_r@opensuse.org
- Update to version 2.3.1
  * Bugfix release
* Mon May 18 2015 dmitry_r@opensuse.org
- Update to version 2.3.0
* Thu Apr 16 2015 dmitry_r@opensuse.org
- Update to version 2.2.1
  * Octave 4.0 compatibility
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.2.0
